"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.AmplifyAngularVisitor = void 0;
const tslib_1 = require("tslib");
const visitor_plugin_common_1 = require("@graphql-codegen/visitor-plugin-common");
const auto_bind_1 = tslib_1.__importDefault(require("auto-bind"));
const graphql_1 = require("graphql");
const change_case_all_1 = require("change-case-all");
class AmplifyAngularVisitor extends visitor_plugin_common_1.ClientSideBaseVisitor {
    constructor(schema, fragments, rawConfig, documents) {
        super(schema, fragments, rawConfig, {}, documents);
        this._operationContent = { interfaces: [], methods: [] };
        (0, auto_bind_1.default)(this);
    }
    getImports() {
        return [
            `/* eslint-disable */`,
            `import { Injectable } from '@angular/core';`,
            `import { API, graphqlOperation } from 'aws-amplify';`,
        ];
    }
    getContent() {
        return [
            ...this._operationContent.interfaces,
            '',
            `@Injectable({`,
            `  providedIn: "root"`,
            `})`,
            'export class GeneratedApiService {',
            ...this._operationContent.methods,
            '}\n',
        ].join('\n');
    }
    buildOperation(node, documentVariableName, operationType, operationResultType, operationVariablesTypes) {
        const serviceName = this.convertName(node);
        const firstChild = node.selectionSet.selections[0];
        let firstChildName;
        const noInput = node.variableDefinitions.length === 0;
        const operationResultTypeName = `${serviceName}Result`;
        if (firstChild.kind === 'Field') {
            firstChildName = firstChild.name.value;
            operationResultType = `${operationResultType}['${firstChildName}']`;
        }
        this._operationContent.interfaces.push(`export type ${operationResultTypeName} = ${operationResultType};`);
        let inputVariables = '';
        let inputArgument = '';
        if (!noInput) {
            inputVariables = ', input';
            inputArgument = `input: ${operationVariablesTypes}`;
        }
        const operations = (0, graphql_1.print)(node);
        const indentedOperations = operations.replace(/\n/g, '\n    ');
        this._operationContent.methods.push(`
  async ${(0, change_case_all_1.camelCase)(serviceName)}(${inputArgument}): Promise<${operationResultTypeName}> {
    const statement = \`${indentedOperations}\`;
    const response = (await API.graphql(
      graphqlOperation(statement${inputVariables})
    )) as any;
    return response.data${firstChildName != null ? `.${firstChildName}` : ''} as ${operationResultTypeName};
  }`);
        return null;
    }
}
exports.AmplifyAngularVisitor = AmplifyAngularVisitor;
//# sourceMappingURL=visitor.js.map